==> kolourpaint_15.12.3.orig.tar.xz: kolourpaint-15.12.3/widgets/colorSimilarity/kpColorSimilarityFrame.cpp <==

/*
   Copyright (c) 2003-2007 Clarence Dang <dang@kde.org>
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   1. Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.

   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


#define DEBUG_KP_COLOR_SIMILARITY_CUBE 0


#include <kpColorSimilarityFrame.h>

#include <kdebug.h>

#include <kpColorSimilarityCubeRenderer.h>

//---------------------------------------------------------------------

kpColorSimilarityFrame::kpColorSimilarityFrame(QWidget *parent)
    : QWidget(parent)
{
    setWhatsThis (WhatsThis ());
}

//---------------------------------------------------------------------

// public virtual [base kpColorSimilarityHolder]
void kpColorSimilarityFrame::setColorSimilarity (double similarity)
{
    kpColorSimilarityHolder::setColorSimilarity (similarity);

    repaint ();
}

//---------------------------------------------------------------------

// protected virtual [base QWidget]
QSize kpColorSimilarityFrame::sizeHint () const
{
    return QSize (52, 52);
}

//---------------------------------------------------------------------

// protected virtual [base QWidget]
void kpColorSimilarityFrame::paintEvent (QPaintEvent *)
{
    int cubeRectSize = qMin(width() * 6 / 8, height() * 6 / 8);
    int x = (width() - cubeRectSize) / 2;
    int y = (height() - cubeRectSize) / 2;

    kpColorSimilarityCubeRenderer::Paint(this,
        x, y, cubeRectSize,
        colorSimilarity());
}

//---------------------------------------------------------------------

==> kolourpaint-16.08.2.tar.xz: kolourpaint-16.08.2/widgets/colorSimilarity/kpColorSimilarityFrame.cpp <==

/*
   Copyright (c) 2003-2007 Clarence Dang <dang@kde.org>
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   1. Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.

   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


#define DEBUG_KP_COLOR_SIMILARITY_CUBE 0


#include "kpColorSimilarityFrame.h"

#include "kpColorSimilarityCubeRenderer.h"

#include <kdebug.h>

//---------------------------------------------------------------------

kpColorSimilarityFrame::kpColorSimilarityFrame(QWidget *parent)
    : QWidget(parent)
{
    setWhatsThis (WhatsThis ());
}

//---------------------------------------------------------------------

// public virtual [base kpColorSimilarityHolder]
void kpColorSimilarityFrame::setColorSimilarity (double similarity)
{
    kpColorSimilarityHolder::setColorSimilarity (similarity);

    repaint ();
}

//---------------------------------------------------------------------

// protected virtual [base QWidget]
QSize kpColorSimilarityFrame::sizeHint () const
{
    return QSize (52, 52);
}

//---------------------------------------------------------------------

// protected virtual [base QWidget]
void kpColorSimilarityFrame::paintEvent (QPaintEvent *)
{
    int cubeRectSize = qMin(width() * 6 / 8, height() * 6 / 8);
    int x = (width() - cubeRectSize) / 2;
    int y = (height() - cubeRectSize) / 2;

    kpColorSimilarityCubeRenderer::Paint(this,
        x, y, cubeRectSize,
        colorSimilarity());
}

//---------------------------------------------------------------------
